﻿#region "GNU General Public License"
/*
 *  Socket Server 2010 provides the ability to to have a socket server for testing
    Copyright (C) 2012  David Welford-Costelloe (http://www.welford-costelloe.org)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#endregion

using System;
using System.Net;
using System.Text.RegularExpressions;

namespace SocketServer2010.Classes
{
    public class Utils
    {
        private const string netWorkType = "InterNetwork";

        /// <summary>
        /// Get the InterNetwork IP address
        /// </summary>
        /// <returns>Local IP</returns>
        public string getIPAddress()
        {
            IPHostEntry iphostentry;
            string sIP = String.Empty;

            iphostentry = Dns.GetHostEntry(Dns.GetHostName());

            foreach (IPAddress ipaddress in iphostentry.AddressList)
            {
                if (ipaddress.AddressFamily.ToString() == netWorkType)
                {
                    sIP = ipaddress.ToString();
                }
            }

            return sIP;
        }

        /// <summary>
        /// Check if IP Address is valid
        /// </summary>
        /// <param name="sIPAddr"></param>
        /// <returns>true or false</returns>
        public bool isValidIPAddress(string sIPAddr)
        {
            Regex check = new Regex(AppConstants.IP_PATTERN_ADDRESS);
            return check.IsMatch(sIPAddr, 0);
        }

        /// <summary>
        /// Get Logged in User ID
        /// </summary>
        /// <returns></returns>
        public string GetUserID()
        {
            return Environment.UserName;
        }

        /// <summary>
        /// Get the Name of the current PC
        /// </summary>
        public string GetMachineName
        {
            get
            {
                return ReturnMachineName();
            }
        }

        /// <summary>
        /// Get the Name of the current PC
        /// </summary>
        private string ReturnMachineName()
        {
            return Environment.MachineName.ToUpper();
        }
    }
}